[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --local-branching-on-the-cheap
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


* * *
The entire **[Pro Git book](https://git-scm.com/book)** written by Scott Chacon and Ben Straub is available to [read online for free](https://git-scm.com/book). Dead tree versions are available on [Amazon.com](https://www.amazon.com/Pro-Git-Scott-Chacon/dp/1484200772?ie=UTF8&camp=1789&creative=9325&creativeASIN=1430218339&linkCode=as2&tag=git-sfconservancy-20).
# Install
Latest version: 2.53.0 ([Release Notes](https://gitlab.com/git-scm/git/-/blob/HEAD/Documentation/RelNotes/2.53.0.adoc))
[ Windows ](https://git-scm.com/install/windows) [ macOS ](https://git-scm.com/install/mac) [ Linux ](https://git-scm.com/install/linux) [ Build from Source ](https://git-scm.com/install/source)
It is easiest to install Git on Linux with your distribution's package manager.
### Debian/Ubuntu
For the latest stable version for your release of Debian/Ubuntu
`# apt-get install git`
For Ubuntu, this PPA provides the latest stable upstream Git version
`# add-apt-repository ppa:git-core/ppa`
`# apt update; apt install git`
### Fedora
`# yum install git` (up to Fedora 21)
`# dnf install git` (Fedora 22 and later)
### Gentoo
`# emerge --ask --verbose dev-vcs/git`
### Arch Linux
`# pacman -S git`
### openSUSE
`# zypper install git`
### Mageia
`# urpmi git`
### Nix/NixOS
`# nix-env -i git`
### FreeBSD
`# pkg install git`
### Solaris 9/10/11 ([OpenCSW](https://www.opencsw.org))
`# pkgutil -i git`
### Solaris 11 Express, OpenIndiana
`# pkg install developer/versioning/git`
### OpenBSD
`# pkg_add git`
### Alpine
`$ apk add git`
### Red Hat Enterprise Linux, Oracle Linux, CentOS, Scientific Linux, et al.
RHEL and derivatives typically ship older versions of git. You can [download a tarball](https://www.kernel.org/pub/software/scm/git/) and build from source, or use a 3rd-party repository such as [the IUS Community Project](https://ius.io/) to obtain a more recent version of git.
### Slitaz
`$ tazpkg get-install git`
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
